#ifndef NT2_INCLUDE_FUNCTIONS_HAVESAMESIZE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_HAVESAMESIZE_HPP_INCLUDED

#include <nt2/predicates/include/functions/havesamesize.hpp>

#endif
